/*******************************************************************************
* File Name: SER_BOOT.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2014-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_SER_H)
#define CY_SCB_BOOT_SER_H

#include "SER_PVT.h"

#if (SER_SCB_MODE_I2C_INC)
    #include "SER_I2C.h"
#endif /* (SER_SCB_MODE_I2C_INC) */

#if (SER_SCB_MODE_EZI2C_INC)
    #include "SER_EZI2C.h"
#endif /* (SER_SCB_MODE_EZI2C_INC) */

#if (SER_SCB_MODE_SPI_INC || SER_SCB_MODE_UART_INC)
    #include "SER_SPI_UART.h"
#endif /* (SER_SCB_MODE_SPI_INC || SER_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define SER_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SER) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (SER_SCB_MODE_I2C_INC)
    #define SER_I2C_BTLDR_COMM_ENABLED     (SER_BTLDR_COMM_ENABLED && \
                                                            (SER_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             SER_I2C_SLAVE_CONST))
#else
     #define SER_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (SER_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (SER_SCB_MODE_EZI2C_INC)
    #define SER_EZI2C_BTLDR_COMM_ENABLED   (SER_BTLDR_COMM_ENABLED && \
                                                         SER_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define SER_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (SER_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (SER_SCB_MODE_SPI_INC)
    #define SER_SPI_BTLDR_COMM_ENABLED     (SER_BTLDR_COMM_ENABLED && \
                                                            (SER_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             SER_SPI_SLAVE_CONST))
#else
        #define SER_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (SER_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (SER_SCB_MODE_UART_INC)
       #define SER_UART_BTLDR_COMM_ENABLED    (SER_BTLDR_COMM_ENABLED && \
                                                            (SER_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (SER_UART_RX_DIRECTION && \
                                                              SER_UART_TX_DIRECTION)))
#else
     #define SER_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (SER_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define SER_BTLDR_COMM_MODE_ENABLED    (SER_I2C_BTLDR_COMM_ENABLED   || \
                                                     SER_SPI_BTLDR_COMM_ENABLED   || \
                                                     SER_EZI2C_BTLDR_COMM_ENABLED || \
                                                     SER_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void SER_I2CCyBtldrCommStart(void);
    void SER_I2CCyBtldrCommStop (void);
    void SER_I2CCyBtldrCommReset(void);
    cystatus SER_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SER_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (SER_SCB_MODE_I2C_CONST_CFG)
        #define SER_CyBtldrCommStart   SER_I2CCyBtldrCommStart
        #define SER_CyBtldrCommStop    SER_I2CCyBtldrCommStop
        #define SER_CyBtldrCommReset   SER_I2CCyBtldrCommReset
        #define SER_CyBtldrCommRead    SER_I2CCyBtldrCommRead
        #define SER_CyBtldrCommWrite   SER_I2CCyBtldrCommWrite
    #endif /* (SER_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void SER_EzI2CCyBtldrCommStart(void);
    void SER_EzI2CCyBtldrCommStop (void);
    void SER_EzI2CCyBtldrCommReset(void);
    cystatus SER_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SER_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (SER_SCB_MODE_EZI2C_CONST_CFG)
        #define SER_CyBtldrCommStart   SER_EzI2CCyBtldrCommStart
        #define SER_CyBtldrCommStop    SER_EzI2CCyBtldrCommStop
        #define SER_CyBtldrCommReset   SER_EzI2CCyBtldrCommReset
        #define SER_CyBtldrCommRead    SER_EzI2CCyBtldrCommRead
        #define SER_CyBtldrCommWrite   SER_EzI2CCyBtldrCommWrite
    #endif /* (SER_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void SER_SpiCyBtldrCommStart(void);
    void SER_SpiCyBtldrCommStop (void);
    void SER_SpiCyBtldrCommReset(void);
    cystatus SER_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SER_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (SER_SCB_MODE_SPI_CONST_CFG)
        #define SER_CyBtldrCommStart   SER_SpiCyBtldrCommStart
        #define SER_CyBtldrCommStop    SER_SpiCyBtldrCommStop
        #define SER_CyBtldrCommReset   SER_SpiCyBtldrCommReset
        #define SER_CyBtldrCommRead    SER_SpiCyBtldrCommRead
        #define SER_CyBtldrCommWrite   SER_SpiCyBtldrCommWrite
    #endif /* (SER_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void SER_UartCyBtldrCommStart(void);
    void SER_UartCyBtldrCommStop (void);
    void SER_UartCyBtldrCommReset(void);
    cystatus SER_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SER_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (SER_SCB_MODE_UART_CONST_CFG)
        #define SER_CyBtldrCommStart   SER_UartCyBtldrCommStart
        #define SER_CyBtldrCommStop    SER_UartCyBtldrCommStop
        #define SER_CyBtldrCommReset   SER_UartCyBtldrCommReset
        #define SER_CyBtldrCommRead    SER_UartCyBtldrCommRead
        #define SER_CyBtldrCommWrite   SER_UartCyBtldrCommWrite
    #endif /* (SER_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_UART_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_BTLDR_COMM_ENABLED)
    #if (SER_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void SER_CyBtldrCommStart(void);
        void SER_CyBtldrCommStop (void);
        void SER_CyBtldrCommReset(void);
        cystatus SER_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus SER_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SER)
        #define CyBtldrCommStart    SER_CyBtldrCommStart
        #define CyBtldrCommStop     SER_CyBtldrCommStop
        #define CyBtldrCommReset    SER_CyBtldrCommReset
        #define CyBtldrCommWrite    SER_CyBtldrCommWrite
        #define CyBtldrCommRead     SER_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SER) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SER_BTLDR_COMM_ENABLED) */


/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define SER_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define SER_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define SER_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define SER_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef SER_SPI_BYTE_TO_BYTE
    #define SER_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef SER_UART_BYTE_TO_BYTE
    #define SER_UART_BYTE_TO_BYTE  (171u)
#endif /* SER_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_SER_H) */


/* [] END OF FILE */
