/*******************************************************************************
* File Name: .h
* Version 3.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_SER_H)
#define CY_SCB_PVT_SER_H

#include "SER.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define SER_SetI2CExtClkInterruptMode(interruptMask) SER_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define SER_ClearI2CExtClkInterruptSource(interruptMask) SER_CLEAR_INTR_I2C_EC(interruptMask)
#define SER_GetI2CExtClkInterruptSource()                (SER_INTR_I2C_EC_REG)
#define SER_GetI2CExtClkInterruptMode()                  (SER_INTR_I2C_EC_MASK_REG)
#define SER_GetI2CExtClkInterruptSourceMasked()          (SER_INTR_I2C_EC_MASKED_REG)

#if (!SER_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define SER_SetSpiExtClkInterruptMode(interruptMask) \
                                                                SER_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define SER_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                SER_CLEAR_INTR_SPI_EC(interruptMask)
    #define SER_GetExtSpiClkInterruptSource()                 (SER_INTR_SPI_EC_REG)
    #define SER_GetExtSpiClkInterruptMode()                   (SER_INTR_SPI_EC_MASK_REG)
    #define SER_GetExtSpiClkInterruptSourceMasked()           (SER_INTR_SPI_EC_MASKED_REG)
#endif /* (!SER_CY_SCBIP_V1) */

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void SER_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (SER_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_SER_CUSTOM_INTR_HANDLER)
    extern cyisraddress SER_customIntrHandler;
#endif /* !defined (CY_REMOVE_SER_CUSTOM_INTR_HANDLER) */
#endif /* (SER_SCB_IRQ_INTERNAL) */

extern SER_BACKUP_STRUCT SER_backup;

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 SER_scbMode;
    extern uint8 SER_scbEnableWake;
    extern uint8 SER_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 SER_mode;
    extern uint8 SER_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * SER_rxBuffer;
    extern uint8   SER_rxDataBits;
    extern uint32  SER_rxBufferSize;

    extern volatile uint8 * SER_txBuffer;
    extern uint8   SER_txDataBits;
    extern uint32  SER_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 SER_numberOfAddr;
    extern uint8 SER_subAddrSize;
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*        Conditional Macro
****************************************/

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define SER_SCB_MODE_I2C_RUNTM_CFG     (SER_SCB_MODE_I2C      == SER_scbMode)
    #define SER_SCB_MODE_SPI_RUNTM_CFG     (SER_SCB_MODE_SPI      == SER_scbMode)
    #define SER_SCB_MODE_UART_RUNTM_CFG    (SER_SCB_MODE_UART     == SER_scbMode)
    #define SER_SCB_MODE_EZI2C_RUNTM_CFG   (SER_SCB_MODE_EZI2C    == SER_scbMode)
    #define SER_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (SER_SCB_MODE_UNCONFIG == SER_scbMode)

    /* Defines wakeup enable */
    #define SER_SCB_WAKE_ENABLE_CHECK       (0u != SER_scbEnableWake)
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!SER_CY_SCBIP_V1)
    #define SER_SCB_PINS_NUMBER    (7u)
#else
    #define SER_SCB_PINS_NUMBER    (2u)
#endif /* (!SER_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_SER_H) */


/* [] END OF FILE */
