/*******************************************************************************
* File Name: main.c
*
* Version: 1.10
*
* Description:
*  This example project demonstrates the basic operation of the SCB component
*  in the UART mode. The polling method is used to wait for received character.
*  As soon as character is received it is transmitted back. The serial terminal
*  can be used on the PC to send characters and get them back.
*  The example will echo every received character.
*
********************************************************************************
* Copyright 2014-2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>

void ProcUARTInterrupt(void);
CY_ISR_PROTO(WDT_ISR_handler);

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  The main function performs the following actions:
*   1. Sets up UART component.
*   2. UART sends text header into the serial terminal.
*   3. UART waits for the characters to send them back to the serial terminal.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
char FlagWDT = 0, FlagSER = 0;

static const char CYCODE MEM_CHAR = 'A';
#define M_CHAR     (*(volatile char*)&MEM_CHAR)

int main()
{
    char ch;
    /* Start SCB (UART mode) operation */
    SER_Init();
    SER_Start();

    WDT_ISR_StartEx(WDT_ISR_handler);
    SER_SetCustomInterruptHandler(&ProcUARTInterrupt);
    Em_EEPROM_1_Start();
    
    CyGlobalIntEnable;

    CyDelay(5u);
    
	/* Setup ISR for interrupts at WDT counter 0 events. */

	
	/* Set WDT counter 2 to generate interrupt for marking ModBus end of packeton */
	CySysWdtWriteMode(CY_SYS_WDT_COUNTER2, CY_SYS_WDT_MODE_INT);
	CySysWdtWriteToggleBit(15);    // One Second Timer
//	CySysWdtWriteClearOnMatch(CY_SYS_WDT_COUNTER0, 1u);
	
	

    for (;;)
    {
//        LED_1_6_Write(1);
	/* Enable WDT counters 0 and 1 */
        LED_1_6_Write(1);
       	if (FlagWDT == 1){
            FlagWDT = 0;
            }
        else{
            CySysWdtEnable(CY_SYS_WDT_COUNTER2_MASK);
            CyDelay(10000u);
        }
        
        if(FlagSER == 1){
            ch = M_CHAR+1;
            SER_UartPutChar(M_CHAR);
            Em_EEPROM_1_Write((uint8*)(&ch), (uint8*)(&M_CHAR), 1);
            FlagSER = 0;
        }
//        CyDelay(5000u);
    }
}


CY_ISR(WDT_ISR_handler)
{
    LED_1_6_Write(0);
    FlagWDT = 1;
	CySysWdtClearInterrupt(CY_SYS_WDT_COUNTER2_INT);
    WDT_ISR_ClearPending();
    CySysWdtDisable(CY_SYS_WDT_COUNTER2_MASK);
    CySysWdtResetCounters(CY_SYS_WDT_COUNTER2_RESET);
}

void ProcUARTInterrupt(void)
{
        uint32 ch;

    if (0u != (SER_GetRxInterruptSourceMasked() & SER_INTR_RX_FIFO_LEVEL))
    {
    /* Interrupt sources does not clear automatically if it is managed by
    * user. The interrupt sources clearing becomes user responsibility.
    */
        SER_ClearRxInterruptSource(SER_INTR_RX_FIFO_LEVEL);
        /* Get received character or zero if nothing has been received yet */
        ch = SER_UartGetChar();

        if (0u != ch)
        {
            /* Transmit the data through UART.
            * This functions is blocking and waits until there is a place in
            * the buffer.
            */
            FlagSER = 1;
            SER_UartPutChar(ch);            

        }
    }
}

/* [] END OF FILE */
